@@ -43,6 +43,7 @@ class FunctionWrapper:
             n_waited = 0
             t = time.perf_counter()
             job_result = self.function(*data, run_specific_data)
+            logging.debug("Result from job: %s" % job_result)
             result_array += job_result
             logging.debug("Total time job took was %.3f, of which %.3f was actual job time" % (time.perf_counter()-t_prev_job, time.perf_counter()-t))
             t_prev_job = time.perf_counter()
@@ -90,6 +91,7 @@ def additative_shared_array_map_reduce(func, mapper, result_array, shared_data,
     t = time.perf_counter()
     for result in result_arrays:
         job_result = object_from_shared_memory(result)
+        logging.debug("Adding result %s" % job_result)
         result_array = result_array +  job_result
     logging.info("Time spent adding results in the end: %.3f" % (time.perf_counter()-t))
 
